#
# spec file for package extractor
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2010 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2013 Marguerite Su <marguerite@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without ffmpeg
%bcond_with libmpeg2
%bcond_with smf

%define soname	        3
%define common_soname   1

Name:           extractor
Version:        1.4
Release:        1.2
Summary:        Library to Extract Metadata from Files
License:        GPL-2.0+
Group:          Productivity/Multimedia/Other
Url:            http://www.gnu.org/software/libextractor/
Source:         libextractor-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  texinfo
BuildRequires:  pkg-config
BuildRequires:  file-devel
BuildRequires:  giflib-devel
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libgsf-1)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(poppler)
BuildRequires:  pkgconfig(rpm)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(zlib)
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec) = 56.60.100
BuildRequires:  pkgconfig(libavformat) = 56.40.101
BuildRequires:  pkgconfig(libavutil) = 54.31.100
BuildRequires:  pkgconfig(libpostproc) = 53.3.100
BuildRequires:  pkgconfig(libswscale) = 3.1.101
%endif
%if %{with libmpeg2}
BuildRequires:  pkgconfig(libmpeg2)
%endif
%if %{with smf}
BuildRequires:  pkgconfig(smf)
%endif
Recommends:     %{name}-plugins = %{version}
Provides:       lib%{name} = 0.5.3
Obsoletes:      lib%{name} < 0.5.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Using libextractor, you can extract metadata from files of arbitrary types.
Supported file formats include HTML, PDF, DVI, PS, MP3, OGG, WAV, JPEG,
GIF, PNG, TIFF, RPM, ZIP, TAR, ELF, REAL, RIFF (AVI), MPEG, QT, and ASF.
Also, various additional MIME types are detected.

This release adds support for Adobe Flash (FLV) and Free Lossless Audio
Codec (FLAC) files. The quicktime, ole2, and split extractors were also
improved.

Helper libraries perform the extraction. It is extendable by linking
against external extractors for additional file types.

The goal is to provide developers of indexing tools with a universal
library to obtain simple keywords to match against queries. libextractor
contains a shell command 'extract' that, similar to the well-known 'file'
command, can extract metadata from a file and print the results to stdout.

The project site is http://savannah.gnu.org/projects/libextractor.

%package -n     lib%{name}%{soname}
Summary:        Shared libraries for the package libextractor
Group:          System/Libraries
Requires:       lib%{name}_common%{common_soname} = %{version}-%{release}
Provides:       %{name}1 = 0.5.3
Obsoletes:      %{name}1 < 0.5.3

%description -n lib%{name}%{soname}
Library to Extract Metadata from Files.

This package contains the shared libraries for the package libextractor.

%package -n     lib%{name}_common%{common_soname}
Summary:        Shared libraries for the package libextractor
Group:          System/Libraries

%description -n lib%{name}_common%{common_soname}
Library to Extract Metadata from Files.

This package contains the shared libraries for the package libextractor.

%package        plugins
Summary:        Plugins for %{name}
Group:          Productivity/Multimedia/Other
Requires:       %{name} = %{version}

%description    plugins
Library to Extract Metadata from Files.

This package contains plugins for %{name}.

%package -n     lib%{name}-devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Languages/C and C++
Requires:       lib%{name}%{soname} = %{version}

%description -n lib%{name}-devel
Library to Extract Metadata from Files.

This package contains all necessary include files and libraries needed to
develop applications that require these.

%lang_package

%prep
%setup -q -n libextractor-%{version}

%build
export CPPFLAGS="%{optflags} -D__STDC_CONSTANT_MACROS -I/usr/include/poppler `pkg-config --cflags libavcodec`"
export CXXFLAGS="%{optflags} -D__STDC_CONSTANT_MACROS -I/usr/include/poppler `pkg-config --cflags libavcodec`"
export CFLAGS="%{optflags} -D__STDC_CONSTANT_MACROS -I/usr/include/poppler `pkg-config --cflags libavcodec`"
rm -rf libltdl
autoreconf -fiv
%configure \
    --disable-ffmpeg \
%if %{with ffmpeg}
    --enable-ffmpeg \
%endif
    --disable-static

find . -name Makefile | xargs sed -i -e 's|-L/usr/lib|-L/%{_libdir}|g'

make \
    %{?_smp_mflags} \
    STRIP=touch

%install
%make_install \
    STRIP=touch

# delete libtool archives
find %{buildroot} -type f -name "*.la" -delete -print

%find_lang lib%{name}

%post   -n lib%{name}%{soname} -p /sbin/ldconfig
%postun -n lib%{name}%{soname} -p /sbin/ldconfig

%post   -n lib%{name}_common%{common_soname} -p /sbin/ldconfig
%postun -n lib%{name}_common%{common_soname} -p /sbin/ldconfig

%post -n lib%{name}-devel
%info_add lib%{name}.info

%postun -n lib%{name}-devel
if [ $1 = 0 ]; then
  %info_del lib%{name}.info
fi

%files lang -f lib%{name}.lang
%defattr(-,root,root)

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README TODO
%{_bindir}/extract
%{_mandir}/man1/extract.1*
%dir %{_libdir}/lib%{name}

%files plugins
%defattr(-,root,root)
%{_libdir}/lib%{name}/lib%{name}_archive.so
%{_libdir}/lib%{name}/lib%{name}_deb.so
%{_libdir}/lib%{name}/lib%{name}_dvi.so
%{_libdir}/lib%{name}/lib%{name}_exiv2.so
%{_libdir}/lib%{name}/lib%{name}_flac.so
%{_libdir}/lib%{name}/lib%{name}_gif.so
%{_libdir}/lib%{name}/lib%{name}_gstreamer.so
%{_libdir}/lib%{name}/lib%{name}_it.so
%{_libdir}/lib%{name}/lib%{name}_jpeg.so
%{_libdir}/lib%{name}/lib%{name}_man.so
%{_libdir}/lib%{name}/lib%{name}_mime.so
%{_libdir}/lib%{name}/lib%{name}_nsf.so
%{_libdir}/lib%{name}/lib%{name}_nsfe.so
%{_libdir}/lib%{name}/lib%{name}_odf.so
%{_libdir}/lib%{name}/lib%{name}_ogg.so
%{_libdir}/lib%{name}/lib%{name}_ole2.so
%{_libdir}/lib%{name}/lib%{name}_pdf.so
%{_libdir}/lib%{name}/lib%{name}_png.so
%{_libdir}/lib%{name}/lib%{name}_ps.so
%{_libdir}/lib%{name}/lib%{name}_riff.so
%{_libdir}/lib%{name}/lib%{name}_rpm.so
%{_libdir}/lib%{name}/lib%{name}_s3m.so
%{_libdir}/lib%{name}/lib%{name}_sid.so
%{_libdir}/lib%{name}/lib%{name}_thumbnailgtk.so
%{_libdir}/lib%{name}/lib%{name}_tiff.so
%{_libdir}/lib%{name}/lib%{name}_wav.so
%{_libdir}/lib%{name}/lib%{name}_xm.so
%{_libdir}/lib%{name}/lib%{name}_zip.so
%if %{with libmpeg2}
%{_libdir}/lib%{name}/lib%{name}_mpeg.so
%endif
%{_libdir}/lib%{name}/lib%{name}_previewopus.so
%if %{with ffmpeg}
%{_libdir}/lib%{name}/lib%{name}_thumbnailffmpeg.so
%endif

%files -n lib%{name}%{soname}
%defattr(-,root,root)
%{_libdir}/libextractor.so.%{soname}
%{_libdir}/libextractor.so.%{soname}.*

%files -n lib%{name}_common%{common_soname}
%defattr(-,root,root)
%{_libdir}/lib%{name}_common.so.%{common_soname}
%{_libdir}/lib%{name}_common.so.%{common_soname}.*

%files -n lib%{name}-devel
%defattr(-,root,root)
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}_common.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_mandir}/man3/libextractor.3*
%{_infodir}/lib%{name}.info.gz

%changelog
* Thu Jul 27 2017 olaf@aepfle.de
- Update to 1.4
* Sat Mar  4 2017 olaf@aepfle.de
- Update to svnrev 37257, adjust Version accordingly
- Fix vorbis requires
- Build with ffmpeg2 unconditional
- Add buildconditional for libmpeg2, for packman
- mp4v2 was dropped, from packman
- Add buildconditional for smf
* Thu Jun 25 2015 avvissu@yandex.ru
- Update to 1.3
- Drop: libextractor-1.2_giflib-5.1.0.patch
- Add %%BUILD_ORIG macro to build in Packman
- Add BuildRequires: pkgconfig(gstreamer-plugins-base-1.0)
- Use pkgconfig in package names
- Add package for plugins
- Add %%info_{add,del} macro
- Spec file cleanup
* Thu May 28 2015 avvissu@yandex.ru
- Fix build on openSUSE > 13.2 (libextractor-1.2_giflib-5.1.0.patch)
* Thu Dec 19 2013 sleep_walker@suse.cz
- bump to 1.2
  * Increase select() timeout, handle timeout case better.
  * Required external installation of libltdl.
  * Check for presence of tidyNodeGetValue in libtidy.
  * Updated Dutch translation.
  * Fix build with libavcodec >= 54.25.0.
- removing libextractor-ffmpeg-2.0.patch as it is not needed anymore
* Sat Jul 27 2013 i@margueirte.su
- update version 1.1
  * xpdf plugin obsoleted
  * qt thumbnail plugin obsoleted
  * applefile plugin obsoleted
  * asf plugin obsoleted
  * elf plugin obsoleted
  * flv plugin obsoleted
  * mkv plugin obsoleted
  * mp3 plugin obsoleted (thus all the id3 plugins)
  * real plugin obsoleted
  * tar plugin obsoleted
  * see http://lists.gnu.org/archive/html/gnunet-svn/2012-08/msg00217.html
- html plugin disabled, 'coz we don't have htmltidy.
- jpeg plugin doesn't work for lower versions. (< 1230)
- gstreamer plugin disabled, 'coz it's experimental.
* Thu May 31 2012 Manfred.Tremmel@iiv.de
- ffmpeg calls are outdated, compile against ffmpeg_oldabi
* Thu Dec  1 2011 pascal.bleser@opensuse.org
- update to 0.6.3
- This release fixes various minor bugs, in particular better handling of
  malloc failures and more robust handling of malformed inputs in various
  plugins.
* Sun Mar 14 2010 toni@links2linux.de
- update to 0.6.1
- This release fixes a problem with LE not finding its plugins under
  certain conditions. It also fixes an IPC issue under FreeBSD which
  caused some plugins to not work.
* Thu Jan 14 2010 toni@links2linux.de
- update to 0.6.0
- new so-name ==> libextractor3
- renamed libextractor to extractor
- removed static library
- This release adds out-of-process execution for plugins and improves
  the quality and quantity of the extracted meta data for many formats.
- It breaks API compatibility.
* Tue Oct 20 2009 toni@links2linux.de
- update to 0.5.23
- This release adds support for librpm 4.7 and uses an external version of
  libexiv2 for improved and more up-to-date EXIV2 support.
* Sat Feb 21 2009 toni@links2linux.de
- update to 0.5.22
- added install-info macros, moved info pages to devel package
* Sun Nov  2 2008 toni@links2linux.de
- update to 0.5.21
* Tue Jul 15 2008 toni@links2linux.de
- update to 0.5.20c
* Sun Apr 27 2008 toni@links2linux.de
- update to 0.5.20b
* Tue Apr 15 2008 toni@links2linux.de
- update to 0.5.20a
* Sun Mar 23 2008 toni@links2linux.de
- update to 0.5.20
* Sun Jan 13 2008 toni@links2linux.de
- update to 0.5.19a
* Mon Jan  7 2008 toni@links2linux.de
- update to 0.5.19
* Sun Sep  2 2007 toni@links2linux.de
- buildOpenSUSE-10.3, fixed BuildRequires
* Mon Jun 25 2007 toni@links2linux.de
- initial build 0.5.18
